@@ -261,8 +261,8 @@ public:
         QPen pen;
         if (WM_HELPER->hasComposite()) {
             auto pixmap = index.data(WindowPreviewContentRole).value<QPixmap>();
-            auto size = calSize(pixmap.size()); 
-            auto scaledPixmap = pixmap.scaled(size, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+            auto size = calSize(pixmap.size());
+            auto scaledPixmap = pixmap.scaled(size, Qt::KeepAspectRatio, Qt::FastTransformation);
             scaledPixmap.setDevicePixelRatio(qApp->devicePixelRatio());
 
             DStyleHelper dstyle(m_listView->style());
@@ -347,7 +347,7 @@ public:
     {
         auto closeButton = new DIconButton(parent);
         closeButton->setIcon(DDciIcon::fromTheme("close"));
-
+        closeButton->setEnabledCircle(true);
         QPalette palette = closeButton->palette();
 
         QColor lightColor = palette.color(QPalette::Normal, QPalette::Light);
@@ -391,6 +391,12 @@ private:
 
 };
 
+const QString AppearanceService = QStringLiteral("org.deepin.dde.Appearance1");
+const QString AppearancePath = QStringLiteral("/org/deepin/dde/Appearance1");
+const QString PropertiesInterface = QStringLiteral("org.freedesktop.DBus.Properties");
+const QString PropertiesChanged = QStringLiteral("PropertiesChanged");
+const QString OpacityStr = QStringLiteral("Opacity");
+
 X11WindowPreviewContainer::X11WindowPreviewContainer(X11WindowMonitor* monitor, QWidget *parent)
     : DBlurEffectWidget(parent)
     , m_direction(0)
@@ -407,9 +413,11 @@ X11WindowPreviewContainer::X11WindowPreviewContainer(X11WindowMonitor* monitor,
     setMouseTracking(true);
     initUI();
 
+    QDBusConnection::sessionBus().connect(AppearanceService, AppearancePath, PropertiesInterface, PropertiesChanged, this, SLOT(onPropertiesChanged(QDBusMessage)));
+
     connect(m_hideTimer, &QTimer::timeout, this, &X11WindowPreviewContainer::callHide);
 
-    connect(m_closeAllButton, &DToolButton::clicked, this, [this](){
+    connect(m_closeAllButton, &DIconButton::clicked, this, [this](){
         if (m_previewItem.isNull()) return;
         for (auto window : m_previewItem->getAppendWindows()) {
             window->close();
@@ -428,6 +436,17 @@ X11WindowPreviewContainer::X11WindowPreviewContainer(X11WindowMonitor* monitor,
 
 }
 
+void X11WindowPreviewContainer::onPropertiesChanged(const QDBusMessage &message)
+{
+    QVariantMap changedProps = qdbus_cast<QVariantMap>(message.arguments().at(1).value<QDBusArgument>());
+    for (QVariantMap::const_iterator it = changedProps.cbegin(); it != changedProps.cend(); ++it) {
+        if (it.key().toLatin1() == OpacityStr) {
+            setMaskAlpha(it.value().toFloat() * 255);
+            return;
+        }
+    }
+}
+
 void X11WindowPreviewContainer::showPreview(const QPointer<AppItem> &item, const QPointer<QWindow> &window, int32_t previewXoffset, int32_t previewYoffset, uint32_t direction)
 {
     if (!m_previewItem.isNull()) {
@@ -575,10 +594,15 @@ void X11WindowPreviewContainer::initUI()
     m_previewIcon->setFixedSize(PREVIEW_TITLE_HEIGHT, PREVIEW_TITLE_HEIGHT);
     m_previewIcon->setScaledContents(true);
 
-    m_closeAllButton = new DToolButton(this);
+    m_closeAllButton = new DIconButton(this);
+
     m_closeAllButton->setIconSize(QSize(16, 16));
-    m_closeAllButton->setIcon(QIcon::fromTheme("close"));
+    m_closeAllButton->setIcon(DDciIcon::fromTheme("close"));
     m_closeAllButton->setFixedSize(PREVIEW_TITLE_HEIGHT, PREVIEW_TITLE_HEIGHT);
+    m_closeAllButton->setEnabledCircle(true);
+
+    DIconButtonHoverFilter *hoverHandler = new DIconButtonHoverFilter(this);
+    m_closeAllButton->installEventFilter(hoverHandler);
 
     m_previewIcon->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
     m_previewTitle->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
