@@ -45,7 +45,7 @@ XcbEventFilter::XcbEventFilter(X11DockHelper *helper)
     m_timer->setInterval(200);
 
     connect(m_timer, &QTimer::timeout, this, [this]() {
-        m_helper->updateHideState(false);
+        m_helper->updateEnterState(false);
     });
     auto *x11Application = qGuiApp->nativeInterface<QNativeInterface::QX11Application>();
     m_connection = x11Application->connection();
@@ -86,8 +86,12 @@ void XcbEventFilter::processEnterLeave(xcb_window_t win, bool enter)
         }
     }
 
+    if (m_helper->dockerWinid() != win) {
+        return;
+    }
+
 // dock enter/leave
-    m_helper->updateHideState(enter);
+    m_helper->updateEnterState(enter);
 }
 
 bool XcbEventFilter::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *)
@@ -101,7 +105,7 @@ bool XcbEventFilter::nativeEventFilter(const QByteArray &eventType, void *messag
         auto eN = reinterpret_cast<xcb_enter_notify_event_t *>(xcb_event);
         qCDebug(dockX11Log) << "enter event winId:" << eN->event;
         if (m_timer->isActive()) {
-            if (!inTriggerArea(eN->event)) {
+            if (m_helper->dockerWinid() == eN->event && !inTriggerArea(eN->event)) {
                 m_timer->stop();
                 break;
             }
@@ -349,8 +353,11 @@ X11DockHelper::X11DockHelper(DockPanel* panel)
     , m_xcbHelper(new XcbEventFilter(this))
     , m_hideState(Show)
     , m_smartHideState(Unknown)
+    , m_enter(true)
 {
-    connect(parent(), &DockPanel::rootObjectChanged, this, &X11DockHelper::createdWakeArea);
+    connect(parent(), &DockPanel::rootObjectChanged, this, &X11DockHelper::updateWakeArea);
+    connect(qApp, &QGuiApplication::screenAdded, this, &X11DockHelper::updateWakeArea);
+    connect(qApp, &QGuiApplication::screenRemoved, this, &X11DockHelper::updateWakeArea);
     connect(panel, &DockPanel::hideStateChanged, this, &X11DockHelper::updateDockTriggerArea);
     connect(panel, &DockPanel::showInPrimaryChanged, this, &X11DockHelper::updateDockTriggerArea);
     connect(panel, &DockPanel::hideModeChanged, this, &X11DockHelper::onHideModeChanged);
@@ -358,7 +365,10 @@ X11DockHelper::X11DockHelper(DockPanel* panel)
     connect(panel, &DockPanel::positionChanged, this, &X11DockHelper::updateDockArea);
     connect(panel, &DockPanel::dockSizeChanged, this, &X11DockHelper::updateDockArea);
     connect(panel, &DockPanel::geometryChanged, this, &X11DockHelper::updateDockArea);
+    connect(panel, &DockPanel::showInPrimaryChanged, this, &X11DockHelper::updateDockArea);
+    connect(panel, &DockPanel::dockScreenChanged, this, &X11DockHelper::updateDockArea);
     connect(panel, &DockPanel::rootObjectChanged, this, [ this, panel ] {
+        m_dockWinid = panel->window()->winId();
         connect(panel->window(), &QWindow::visibleChanged, this, &X11DockHelper::updateWindowState, Qt::UniqueConnection);
         updateWindowState();
     });
@@ -380,6 +390,14 @@ void X11DockHelper::updateDockTriggerArea()
     }
 }
 
+void X11DockHelper::updateEnterState(bool enter)
+{
+    if(m_enter!= enter) {
+        m_enter = enter;
+        updateHideState();
+    }
+}
+
 void X11DockHelper::onHideModeChanged(HideMode mode)
 {
     // 会收到重复信号，因此每次都清理下数据
@@ -400,10 +418,7 @@ void X11DockHelper::onHideModeChanged(HideMode mode)
         delayedUpdateState();
     } break;
     case KeepShowing:
-        updateHideState(true);
-        break;
     case KeepHidden:
-        updateHideState(false);
         break;
     default: {
 
@@ -490,7 +505,7 @@ void X11DockHelper::updateSmartHideState(const HideState &state)
         m_smartHideState = state;
         qCDebug(dockX11Log) << "smart hide state:" << m_smartHideState;
         if (parent()->hideMode() == SmartHide) {
-            updateHideState(m_smartHideState == Show);
+            updateHideState();
         }
     }
 }
@@ -548,6 +563,9 @@ void X11DockHelper::updateDockArea()
     }
     if (m_dockArea != rect) {
         m_dockArea = rect;
+        for (auto it = m_windows.cbegin(); it != m_windows.cend(); ++it) {
+            updateWindowHideState(it.key());
+        }
         delayedUpdateState();
     }
 }
@@ -567,23 +585,39 @@ HideState X11DockHelper::hideState()
     return m_hideState;
 }
 
-void X11DockHelper::updateHideState(bool show)
+void X11DockHelper::updateHideState()
 {
-    if (show) {
-        m_hideState = Show;
+    auto hideState = Show;
+    if (m_enter) {
+        hideState = Show;
     } else {
         if (parent()->hideMode() == HideMode::SmartHide && m_smartHideState == Show) {
-            return;
+            hideState = Show;
+        } else {
+            hideState = Hide;
         }
-        m_hideState = Hide;
     }
-    Q_EMIT hideStateChanged();
+    if (m_hideState != hideState) {
+        m_hideState = hideState;
+        Q_EMIT hideStateChanged();
+    }
 }
 
-void X11DockHelper::createdWakeArea()
+void X11DockHelper::updateWakeArea()
 {
-    for (auto screen: qApp->screens()) {
-        DockTriggerArea* area = new DockTriggerArea(parent(), this, screen);
+    auto screens = qApp->screens();
+    for (auto it = m_areas.begin(); it != m_areas.end();) {
+        if (screens.contains((*it)->screen())) {
+            screens.removeOne((*it)->screen());
+            ++it;
+        } else {
+            delete (*it);
+            it = m_areas.erase(it);
+        }
+    }
+
+    for (auto screen : screens) {
+        DockTriggerArea *area = new DockTriggerArea(parent(), this, screen);
         m_areas.append(area);
     }
 }
@@ -723,7 +757,7 @@ void DockTriggerArea::onTriggerTimer()
         m_panel->setDockScreen(m_screen);
         m_helper->updateDockTriggerArea();
     }
-    m_panel->setHideState(Show);
+    m_helper->updateEnterState(true);
 }
 void DockTriggerArea::onHoldingTimer()
 {
